@@ -1,8 +1,11 @@
+# -*- coding: utf-8 -*-
+#
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2000-2007  Donald N. Allingham
 # Copyright (C) 2008-2009  Brian G. Matherly
 # Copyright (C) 2009       Rob G. Healey <robhealey1@gmail.com>
+# Copyright (C) 2014       Vlada Perić <vlada.peric@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,31 +19,27 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+
 #------------------------------------------------------------------------
 #
 # python modules
 #
 #------------------------------------------------------------------------
-from __future__ import print_function
-
-from gramps.gen.const import GRAMPS_LOCALE as glocale
-_ = glocale.translation.gettext
 from xml.parsers import expat
-from gramps.gen.lib.calendar import (gregorian_ymd, hebrew_sdn)
 import datetime
 import math
-from gramps.gen.const import PLUGINS_DIR, USER_PLUGINS
 import os
-import sys
 
 #------------------------------------------------------------------------
 #
 # GRAMPS modules
 #
 #------------------------------------------------------------------------
-from gramps.gen.constfunc import STRTYPE
+from gramps.gen.const import GRAMPS_LOCALE as glocale
+_ = glocale.translation.gettext
+from gramps.gen.const import PLUGINS_DIR, USER_PLUGINS
+from gramps.gen.lib.gcalendar import (gregorian_ymd, hebrew_sdn)
 
 #------------------------------------------------------------------------
 #
@@ -60,18 +59,42 @@ def easter(year):
     to the Astronomical Almanac", ed. P. K.  Seidelmann (1992).  Note:
     Ash Wednesday is 46 days before Easter Sunday.
     """
-    c = year / 100
-    n = year - 19 * (year / 19)
-    k = (c - 17) / 25
-    i = c - c / 4 - (c - k) / 3 + 19 * n + 15
-    i = i - 30 * (i / 30)
-    i = i - (i / 28) * (1 - (i / 28) * (29 / (i + 1))
-                           * ((21 - n) / 11))
-    j = year + year / 4 + i + 2 - c + c / 4
-    j = j - 7 * (j / 7)
+    c = year // 100
+    n = year - 19 * (year // 19)
+    k = (c - 17) // 25
+    i = c - c // 4 - (c - k) // 3 + 19 * n + 15
+    i = i - 30 * (i // 30)
+    i = i - (i // 28) * (1 - (i // 28) * (29 // (i + 1)) * ((21 - n) // 11) )
+    j = year + year // 4 + i + 2 - c + c // 4
+    j = j - 7 * (j // 7)
     l = i - j
-    month = 3 + (l + 40) / 44
-    day = l + 28 - 31 * (month / 4)
+    month = 3 + (l + 40) // 44
+    day = l + 28 - 31 * (month // 4)
+    return "%d/%d/%d" % (year, month, day)
+
+def julian_easter(year):
+    """
+    Computes the year/month/day of Eastern Orthodox Easter, given in the
+    Gregorian calendar. Implements the Jean Meeus algorithm. Valid: 1900-2099.
+    """
+    a = year % 4
+    b = year % 7
+    c = year % 19
+    d = (19*c + 15) % 30
+    e = (2*a + 4*b - d + 34) % 7
+    month = int(math.floor((d + e + 114) / 31))
+    day = ((d + e + 114) % 31) + 1
+
+    # produced date was in the Julian calendar, add 13 days to it
+    day = day + 13
+
+    if month == 3 and day > 31:
+        day = day - 31
+        month = 4
+    elif month == 4 and day > 30:
+        day = day - 30
+        month = 5
+
     return "%d/%d/%d" % (year, month, day)
 
 def passover(year):
@@ -115,6 +138,12 @@ def dow(y, m, d):
     """ Return the ISO day of week for the given year, month and day. """
     return datetime.date(y, m, d).isoweekday()
 
+def cmp(a, b):
+    """
+    Replacement for older Python's cmp.
+    """
+    return (a > b) - (a < b)
+
 #------------------------------------------------------------------------
 #
 # HolidayTable
@@ -282,7 +311,7 @@ class _Xml2Obj:
     def start_element(self, name, attributes):
         'SAX start element even handler'
         # Instantiate an Element object
-        element = _Element(name.encode(), attributes)
+        element = _Element(name, attributes)
         # Push element onto the stack and make it a child of parent
         if len(self.nodeStack) > 0:
             parent = self.nodeStack[-1]
@@ -302,10 +331,7 @@ class _Xml2Obj:
         parser.StartElementHandler = self.start_element
         parser.EndElementHandler = self.end_element
         # Parse the XML File
-        if sys.version_info[0] < 3:
-            parser.Parse(open(filename, 'r').read(), 1)
-        else:
-            parser.Parse(open(filename, 'rb').read(), 1)
+        parser.Parse(open(filename, 'rb').read(), 1)
         return self.root
 
 #------------------------------------------------------------------------
@@ -439,7 +465,7 @@ class _Holidays:
             if isinstance(offset, int):
                 if offset != 0:
                     ndate = ndate.fromordinal(ndate.toordinal() + offset)
-            elif isinstance(offset, STRTYPE):
+            elif isinstance(offset, str):
                 direction = 1
                 if offset[0] == "-":
                     direction = -1
